{
	"name" : "Product extension to track sales and purchases",
	"version" : "1.0",
	"author" : "Tiny",
	"depends" : ["product", "purchase", "sale"],
	"category" : "Generic Modules/Inventory Control",
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["product_extended_view.xml"],
	"active": False,
	"installable": True
}
